Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1816)

Unified Diff: third_party/WebKit/public/platform/modules/remoteplayback/WebRemotePlaybackClient.h

Issue 2345863002: [Blink, RemotePlayback] Rename connect() to prompt() (Closed)
Patch Set: Rebase Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/modules/remoteplayback/RemotePlayback.idl ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/platform/modules/remoteplayback/WebRemotePlaybackClient.h
diff --git a/third_party/WebKit/public/platform/modules/remoteplayback/WebRemotePlaybackClient.h b/third_party/WebKit/public/platform/modules/remoteplayback/WebRemotePlaybackClient.h
index 0f977ab594c7d445b103acd0a322ecdf9cea53de..12bcbcdda7c5a47890fed661a93b318b4a45af11 100644
--- a/third_party/WebKit/public/platform/modules/remoteplayback/WebRemotePlaybackClient.h
+++ b/third_party/WebKit/public/platform/modules/remoteplayback/WebRemotePlaybackClient.h
@@ -20,8 +20,8 @@ public:
// Notifies the client of the remote playback device availability change.
virtual void availabilityChanged(bool availability) = 0;
- // Notifies the client that the user cancelled connection to remote device.
- virtual void connectCancelled() = 0;
+ // Notifies the client that the user cancelled the prompt shown via the API.
+ virtual void promptCancelled() = 0;
};
} // namespace blink
« no previous file with comments | « third_party/WebKit/Source/modules/remoteplayback/RemotePlayback.idl ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698